@@ -3,9 +3,9 @@
 use super::service_ref::ManagedDNSServiceRef;
 use crate::event_loop::TEventLoop;
 use crate::{ffi, Result};
+use std::marker::PhantomData;
 use std::sync::{Arc, Mutex};
 use std::time::Duration;
-use std::marker::PhantomData;
 
 #[derive(new)]
 pub struct BonjourEventLoop<'a> {
@@ -21,7 +21,7 @@ impl<'a> TEventLoop for BonjourEventLoop<'a> {
     /// new data, the blocking call is not made.
     fn poll(&self, timeout: Duration) -> Result<()> {
         let service = self.service.lock().unwrap();
-        let select = unsafe { ffi::read_select(service.sock_fd(), timeout)? };
+        let select = unsafe { ffi::macos::read_select(service.sock_fd(), timeout)? };
         if select > 0 {
             service.process_result()
         } else {
