@@ -3,7 +3,7 @@ use std::sync::Once;
 static INIT: Once = Once::new();
 
 pub(crate) fn setup() {
-    INIT.call_once(|| env_logger::init());
+    INIT.call_once(env_logger::init);
 }
 
 mod service_test;
